%GeometryRotorInsetPMThermal.m
%%%%%%%%%%%
%Draw the geometry for an inset PM rotor

function [Out]=GeometryRotorInsetPMThermal(ShaftRad,PolePitch,NoOfArcSegments, ...
               RotorRad,MagnetHeight,MagnetArcAngle,MagnetLeakageFluxBarrierAngle, ...
               MeshShaft,MeshRotor,MeshAirGap,p)


%Create the shaft nodes and corresponding arc
hi_clearselected();
PxShaft=ShaftRad*sin(PolePitch/2);
PyShaft=ShaftRad*cos(PolePitch/2);
hi_addnode(PxShaft,PyShaft); 
hi_addnode(-PxShaft,PyShaft); 
hi_addarc(PxShaft,PyShaft,-PxShaft,PyShaft,PolePitch*180/pi,NoOfArcSegments); 

%Create the nodes corresponding to the outer arc of the rotor magnet (and draw the corresponding arc)
hi_clearselected();
PxRotorMagnetOuterRad=(RotorRad+MagnetHeight)*sin(MagnetArcAngle/2);
PyRotorMagnetOuterRad=(RotorRad+MagnetHeight)*cos(MagnetArcAngle/2);
hi_addnode(PxRotorMagnetOuterRad,PyRotorMagnetOuterRad); 
hi_addnode(-PxRotorMagnetOuterRad,PyRotorMagnetOuterRad); 
hi_addarc(PxRotorMagnetOuterRad,PyRotorMagnetOuterRad,-PxRotorMagnetOuterRad,PyRotorMagnetOuterRad,MagnetArcAngle*180/pi,NoOfArcSegments);

%Create the nodes corresponding to the inner arc of the rotor magnet (and draw the corresponding arc)
hi_clearselected();
PxRotorMagnetInnerRad=RotorRad*sin(MagnetArcAngle/2);
PyRotorMagnetInnerRad=RotorRad*cos(MagnetArcAngle/2);
hi_addnode(PxRotorMagnetInnerRad,PyRotorMagnetInnerRad); 
hi_addnode(-PxRotorMagnetInnerRad,PyRotorMagnetInnerRad); 
hi_addarc(PxRotorMagnetInnerRad,PyRotorMagnetInnerRad,-PxRotorMagnetInnerRad,PyRotorMagnetInnerRad,MagnetArcAngle*180/pi,NoOfArcSegments);

%Create the lines corresponding to the sides of the rotor magnet
hi_addsegment(PxRotorMagnetInnerRad,PyRotorMagnetInnerRad,PxRotorMagnetOuterRad,PyRotorMagnetOuterRad);
hi_addsegment(-PxRotorMagnetInnerRad,PyRotorMagnetInnerRad,-PxRotorMagnetOuterRad,PyRotorMagnetOuterRad);

%Create the nodes corresponding to the outermost part of the rotor lamination (and draw the corresponding arcs and lines)
hi_clearselected();
PxRotorLaminationOuterRad1=(RotorRad+MagnetHeight)*sin(PolePitch/2);
PyRotorLaminationOuterRad1=(RotorRad+MagnetHeight)*cos(PolePitch/2);
PxRotorLaminationOuterRad2=(RotorRad+MagnetHeight)*sin(MagnetArcAngle/2+MagnetLeakageFluxBarrierAngle);
PyRotorLaminationOuterRad2=(RotorRad+MagnetHeight)*cos(MagnetArcAngle/2+MagnetLeakageFluxBarrierAngle);
hi_addnode(PxRotorLaminationOuterRad1,PyRotorLaminationOuterRad1); 
hi_addnode(PxRotorLaminationOuterRad2,PyRotorLaminationOuterRad2); 
hi_addarc(PxRotorLaminationOuterRad1,PyRotorLaminationOuterRad1,PxRotorLaminationOuterRad2,PyRotorLaminationOuterRad2,(PolePitch/2-MagnetArcAngle/2-MagnetLeakageFluxBarrierAngle/2)*180/pi,NoOfArcSegments);
hi_clearselected();
hi_addnode(-PxRotorLaminationOuterRad1,PyRotorLaminationOuterRad1); 
hi_addnode(-PxRotorLaminationOuterRad2,PyRotorLaminationOuterRad2); 
hi_addarc(-PxRotorLaminationOuterRad2,PyRotorLaminationOuterRad2,-PxRotorLaminationOuterRad1,PyRotorLaminationOuterRad1,(PolePitch/2-MagnetArcAngle/2-MagnetLeakageFluxBarrierAngle/2)*180/pi,NoOfArcSegments);
hi_clearselected();
PxRotorLaminationInnerRad=RotorRad*sin(MagnetArcAngle/2+MagnetLeakageFluxBarrierAngle);
PyRotorLaminationInnerRad=RotorRad*cos(MagnetArcAngle/2+MagnetLeakageFluxBarrierAngle);
hi_addnode(PxRotorLaminationInnerRad,PyRotorLaminationInnerRad); 
hi_addnode(-PxRotorLaminationInnerRad,PyRotorLaminationInnerRad); 
hi_addarc(PxRotorMagnetInnerRad,PyRotorMagnetInnerRad,PxRotorLaminationInnerRad,PyRotorLaminationInnerRad,MagnetLeakageFluxBarrierAngle*180/pi,NoOfArcSegments);
hi_addarc(-PxRotorMagnetInnerRad,PyRotorMagnetInnerRad,-PxRotorLaminationInnerRad,PyRotorLaminationInnerRad,MagnetLeakageFluxBarrierAngle*180/pi,NoOfArcSegments);
hi_clearselected();
hi_addsegment(PxRotorLaminationInnerRad,PyRotorLaminationInnerRad,PxRotorLaminationOuterRad2,PyRotorLaminationOuterRad2);
hi_addsegment(-PxRotorLaminationInnerRad,PyRotorLaminationInnerRad,-PxRotorLaminationOuterRad2,PyRotorLaminationOuterRad2);

%Set properties for the arc corresponding to the shaft
hi_clearselected();
hi_selectarcsegment(0,ShaftRad);
hi_setarcsegmentprop((MeshShaft/ShaftRad)*180/pi,'UnSpec',0,2,'<None>');   %UnSpec is a not defined boundary

%Set properties for the arc corresponding to the inner arc of the rotor magnet
hi_clearselected();
hi_selectarcsegment(0,RotorRad);
hi_setarcsegmentprop((MeshRotor/RotorRad)*180/pi,'UnSpec',0,2,'<None>');   %UnSpec is a not defined boundary

%Set properties for the arc corresponding to the outer arc of the rotor magnet
hi_clearselected();
hi_selectarcsegment(0,RotorRad+MagnetHeight);
hi_setarcsegmentprop((MeshAirGap/(RotorRad+MagnetHeight))*180/pi,'UnSpec',0,2,'<None>');   %UnSpec is a not defined boundary

%Set properties for the lines corresponding to the sides of the rotor magnet
hi_clearselected();
hi_selectsegment(PxRotorMagnetInnerRad/2+PxRotorMagnetOuterRad/2,PyRotorMagnetInnerRad/2+PyRotorMagnetOuterRad/2);
hi_setsegmentprop('UnSpec',MeshAirGap,0,0,2,'<None>');    %UnSpec is a not defined boundary
hi_clearselected();
hi_selectsegment(-PxRotorMagnetInnerRad/2-PxRotorMagnetOuterRad/2,PyRotorMagnetInnerRad/2+PyRotorMagnetOuterRad/2);
hi_setsegmentprop('UnSpec',MeshAirGap,0,0,2,'<None>');    %UnSpec is a not defined boundary

%Set the properties for the arc corresponding to the outermost radii of the rotor lamination
hi_clearselected();
hi_selectarcsegment((RotorRad+MagnetHeight)*sin(PolePitch/2-MagnetLeakageFluxBarrierAngle),(RotorRad+MagnetHeight)*cos(PolePitch/2-MagnetLeakageFluxBarrierAngle));
hi_setarcsegmentprop((MeshRotor/(RotorRad+MagnetHeight))*180/pi,'UnSpec',0,2,'<None>');   %UnSpec is a not defined boundary
hi_clearselected();
hi_selectarcsegment(-(RotorRad+MagnetHeight)*sin(PolePitch/2-MagnetLeakageFluxBarrierAngle),(RotorRad+MagnetHeight)*cos(PolePitch/2-MagnetLeakageFluxBarrierAngle));
hi_setarcsegmentprop((MeshRotor/(RotorRad+MagnetHeight))*180/pi,'UnSpec',0,2,'<None>');   %UnSpec is a not defined boundary

%Set the properties for the lines corresponding to the rotor laminations siding the rotor magnets
hi_clearselected();
hi_selectsegment((RotorRad+0.5*MagnetHeight)*sin(0.5*MagnetArcAngle+MagnetLeakageFluxBarrierAngle),(RotorRad+0.5*MagnetHeight)*cos(0.5*MagnetArcAngle+MagnetLeakageFluxBarrierAngle));
hi_setsegmentprop('UnSpec',MeshAirGap,0,0,2,'<None>');    %UnSpec is a not defined boundary
hi_clearselected();
hi_selectsegment(-(RotorRad+0.5*MagnetHeight)*sin(0.5*MagnetArcAngle+MagnetLeakageFluxBarrierAngle),(RotorRad+0.5*MagnetHeight)*cos(0.5*MagnetArcAngle+MagnetLeakageFluxBarrierAngle));
hi_setsegmentprop('UnSpec',MeshAirGap,0,0,2,'<None>');    %UnSpec is a not defined boundary

%Set the properties for the small arcs siding the rotor magnets
hi_clearselected();
hi_selectarcsegment(RotorRad*sin(0.5*MagnetArcAngle+0.5*MagnetLeakageFluxBarrierAngle),RotorRad*cos(0.5*MagnetArcAngle+0.5*MagnetLeakageFluxBarrierAngle));
hi_setarcsegmentprop((MeshRotor/RotorRad)*180/pi,'UnSpec',0,2,'<None>');   %UnSpec is a not defined boundary
hi_clearselected();
hi_selectarcsegment(-RotorRad*sin(0.5*MagnetArcAngle+0.5*MagnetLeakageFluxBarrierAngle),RotorRad*cos(0.5*MagnetArcAngle+0.5*MagnetLeakageFluxBarrierAngle));
hi_setarcsegmentprop((MeshRotor/RotorRad)*180/pi,'UnSpec',0,2,'<None>');   %UnSpec is a not defined boundary

%Rotational copy of the rotor
hi_clearselected();
hi_seteditmode('group');
hi_selectgroup(2);  %Select the rotor
hi_copyrotate(0,0,PolePitch*180/pi,p-1);

hi_zoomnatural();
Out=1;