%GeometryStatorThermal.m
%%%%%%%%%%%
%Defines the geometry and the mesh of the magnetic FEMM simulation 

function [Out]=GeometryStatorThermal(ia,ib,ic,StatorRad,SlotPitch,RotorRad, ...
            AirGapHeight,ToothOpeningWidth,InnerToothTipHeight, ...
            OuterToothTipHeight,NoOfArcSegments,ToothWidth, ...
            ToothHeight,MeshStatorLam,StatorBackThickness, ...
            MeshAirGap,Qs,TAmbient,hCyl,EnclosureRad)

%Create origo and exterior stator nodes
hi_addnode(0,0);    %Origo
PxOut=StatorRad*sin(SlotPitch/2);
PyOut=StatorRad*cos(SlotPitch/2);
hi_addnode(PxOut,PyOut);
hi_addnode(-PxOut,PyOut);
PxIn=(RotorRad+AirGapHeight)*sin(SlotPitch/2);
PyIn=(RotorRad+AirGapHeight)*cos(SlotPitch/2);
hi_addnode(PxIn,PyIn);
hi_addnode(-PxIn,PyIn);
  
%Create the stator slot nodes
hi_clearselected();
ThetaSlotTip=(ToothOpeningWidth/2)/(RotorRad+AirGapHeight); %Angle from mid of slot to a tooth tip [rad]
PxInnerToothTip1=(RotorRad+AirGapHeight)*sin(ThetaSlotTip);
PyInnerToothTip1=(RotorRad+AirGapHeight)*cos(ThetaSlotTip);
hi_addnode(PxInnerToothTip1,PyInnerToothTip1);
hi_addnode(-PxInnerToothTip1,PyInnerToothTip1);
PxInnerToothTip2=(RotorRad+AirGapHeight+InnerToothTipHeight)*sin(ThetaSlotTip);
PyInnerToothTip2=(RotorRad+AirGapHeight+InnerToothTipHeight)*cos(ThetaSlotTip);
hi_addnode(PxInnerToothTip2,PyInnerToothTip2);
hi_addnode(-PxInnerToothTip2,PyInnerToothTip2);

ThetaSlotIn=SlotPitch/2-(ToothWidth/2)*(1/(RotorRad+AirGapHeight+OuterToothTipHeight)); %Angle from mid of slot to a tooth [rad]
PxInnerSlot=(RotorRad+AirGapHeight+OuterToothTipHeight)*sin(ThetaSlotIn);
PyInnerSlot=(RotorRad+AirGapHeight+OuterToothTipHeight)*cos(ThetaSlotIn);
hi_addnode(PxInnerSlot,PyInnerSlot);
hi_addnode(-PxInnerSlot,PyInnerSlot);
ThetaSlotOut=SlotPitch/2-(ToothWidth/2)*(1/(RotorRad+AirGapHeight+OuterToothTipHeight+ToothHeight)); %Angle from mid of slot to a tooth [rad]
PxOuterSlot=(RotorRad+AirGapHeight+OuterToothTipHeight+ToothHeight)*sin(ThetaSlotOut);
PyOuterSlot=(RotorRad+AirGapHeight+OuterToothTipHeight+ToothHeight)*cos(ThetaSlotOut);
hi_addnode(PxOuterSlot,PyOuterSlot);
hi_addnode(-PxOuterSlot,PyOuterSlot);

%Draw outer periphery arc
hi_addarc(StatorRad*sin(SlotPitch/2),StatorRad*cos(SlotPitch/2),-StatorRad*sin(SlotPitch/2),StatorRad*cos(SlotPitch/2),SlotPitch*180/pi,NoOfArcSegments);

%Draw arc corresponding to inner stator back
hi_addarc(PxOuterSlot,PyOuterSlot,-PxOuterSlot,PyOuterSlot,2*ThetaSlotIn*180/pi,NoOfArcSegments);
 
%Draw arc corresponding to inner tooth tip
hi_addarc(PxIn,PyIn,PxInnerToothTip1,PyInnerToothTip1,(SlotPitch/2-ThetaSlotTip)*180/pi,NoOfArcSegments);
hi_addarc(-PxInnerToothTip1,PyInnerToothTip1,-PxIn,PyIn,(SlotPitch/2-ThetaSlotTip)*180/pi,NoOfArcSegments);
 
%Create the stator slot lines
hi_addsegment(PxInnerToothTip1,PyInnerToothTip1,PxInnerToothTip2,PyInnerToothTip2);
hi_addsegment(-PxInnerToothTip1,PyInnerToothTip1,-PxInnerToothTip2,PyInnerToothTip2);
hi_addsegment(PxInnerToothTip2,PyInnerToothTip2,PxInnerSlot,PyInnerSlot);
hi_addsegment(-PxInnerToothTip2,PyInnerToothTip2,-PxInnerSlot,PyInnerSlot);
hi_addsegment(PxInnerSlot,PyInnerSlot,PxOuterSlot,PyOuterSlot);
hi_addsegment(-PxInnerSlot,PyInnerSlot,-PxOuterSlot,PyOuterSlot);
 
%Draw lines corresponding to the stator slot pitch
hi_addsegment(PxIn,PyIn,PxOut,PyOut);
hi_addsegment(-PxIn,PyIn,-PxOut,PyOut);
 
%Draw arc corresponding to the stator slot wedge
hi_addarc(PxInnerToothTip1,PyInnerToothTip1,-PxInnerToothTip1,PyInnerToothTip1,ThetaSlotTip*180/pi,NoOfArcSegments); %Inner part of slot wedge
hi_addarc(PxInnerToothTip2,PyInnerToothTip2,-PxInnerToothTip2,PyInnerToothTip2,2*atan(PxInnerToothTip2/PyInnerToothTip2)*180/pi,NoOfArcSegments); %Outer part of slot wedge

%Draw nodes and arc of the stator enclosure (outer radius)
PxEncOut=EnclosureRad*sin(SlotPitch/2);
PyEncOut=EnclosureRad*cos(SlotPitch/2);
hi_addnode(PxEncOut,PyEncOut);
hi_addnode(-PxEncOut,PyEncOut);
hi_addarc(EnclosureRad*sin(SlotPitch/2),EnclosureRad*cos(SlotPitch/2),-EnclosureRad*sin(SlotPitch/2),EnclosureRad*cos(SlotPitch/2),SlotPitch*180/pi,NoOfArcSegments);

%Grouping of nodes, arcs and lines and define mesh densities%%%%%%%%%%%%%%%
%Group 1: Stator
%Group 2: Rotor (including shaft)
  
%Group stator exterior nodes
hi_clearselected();
hi_selectnode(PxOut,PyOut);
hi_selectnode(-PxOut,PyOut);
hi_selectnode(PxIn,PyIn);
hi_selectnode(-PxIn,PyIn);
hi_selectnode(PxInnerToothTip1,PyInnerToothTip1);
hi_selectnode(-PxInnerToothTip1,PyInnerToothTip1);
hi_selectnode(PxEncOut,PyEncOut);
hi_selectnode(-PxEncOut,PyEncOut);
hi_setnodeprop('StatorExt',1,'<None>'); %Name the group 'StatorExt' and let it belong to group number 1
  
%Group the stator slot nodes
hi_clearselected();
hi_selectnode(PxOuterSlot,PyOuterSlot);
hi_selectnode(-PxOuterSlot,PyOuterSlot);
hi_selectnode(PxInnerToothTip2,PyInnerToothTip2);
hi_selectnode(-PxInnerToothTip2,PyInnerToothTip2);
hi_selectnode(PxInnerSlot,PyInnerSlot);
hi_selectnode(-PxInnerSlot,PyInnerSlot);
hi_setnodeprop('Slot',1,'<None>'); %Name the group 'Slot' and let it belong to group number 1
 
%Set properties for the arcs corresponding to the outer stator enclosure and the stator back
hi_clearselected();
hi_addboundprop('AmbConv',2, 0, 0, TAmbient, hCyl, 0); %Define the boundary condition correspondin to heat transfer by convection to the ambient
%hi_addboundprop('AmbConv',0, 273, 0, 0, 0, 0); %Fixed outetr temperature (not used)
hi_selectarcsegment(0,EnclosureRad);
hi_setarcsegmentprop((MeshStatorLam/EnclosureRad)*180/pi,'AmbConv',0,1,'<None>');
hi_clearselected();
hi_selectarcsegment(0,StatorRad-StatorBackThickness);
hi_setarcsegmentprop((MeshStatorLam/StatorRad)*180/pi,'UnSpec',0,1,'<None>');   %UnSpec is a not defined boundary
hi_clearselected();
hi_selectarcsegment(0,StatorRad);
hi_setarcsegmentprop((MeshStatorLam/StatorRad)*180/pi,'UnSpec',0,1,'<None>');   %UnSpec is a not defined boundary

%Set properties for the lines corresponding to the stator teeth
hi_clearselected();
hi_selectsegment((StatorRad-0.01*ToothHeight)*sin(0.5*SlotPitch),(StatorRad-0.01*ToothHeight)*cos(0.5*SlotPitch));
hi_selectsegment(-(StatorRad-0.01*ToothHeight)*sin(0.5*SlotPitch),(StatorRad-0.01*ToothHeight)*cos(0.5*SlotPitch));
hi_selectsegment((StatorRad-StatorBackThickness-0.01*ToothHeight)*sin(1*ThetaSlotIn),(StatorRad-StatorBackThickness-0.01*ToothHeight)*cos(1*ThetaSlotIn));
hi_selectsegment(-(StatorRad-StatorBackThickness-0.01*ToothHeight)*sin(1*ThetaSlotIn),(StatorRad-StatorBackThickness-0.01*ToothHeight)*cos(1*ThetaSlotIn));
hi_setsegmentprop('UnSpec',MeshStatorLam,0,0,1,'<None>');    %UnSpec is a not defined boundary
  
%Set properties for the lines corresponding to the inner parts of the stator tooth tips and the outer part of the stator slot wedge
hi_clearselected();
PxToothTipLine=0.5*(PxInnerToothTip2+PxInnerSlot);
PyToothTipLine=PyInnerToothTip2+0.5*(PxInnerSlot-PxInnerToothTip2)*(PyInnerSlot-PyInnerToothTip2)/((PxInnerSlot-PxInnerToothTip2));
hi_selectsegment(PxToothTipLine,PyToothTipLine);
hi_selectsegment(-PxToothTipLine,PyToothTipLine);
hi_setsegmentprop('UnSpec',MeshStatorLam,0,0,1,'<None>');    %UnSpec is a not defined boundary
hi_clearselected();
hi_selectarcsegment(0,RotorRad+AirGapHeight+InnerToothTipHeight);
hi_setarcsegmentprop((MeshStatorLam/(RotorRad+AirGapHeight+InnerToothTipHeight))*180/pi,'UnSpec',0,1,'<None>');   %UnSpec is a not defined boundary
hi_clearselected();
hi_selectsegment((RotorRad+AirGapHeight+0.5*InnerToothTipHeight)*sin(ThetaSlotTip),(RotorRad+AirGapHeight+0.5*InnerToothTipHeight)*cos(ThetaSlotTip));
hi_selectsegment(-(RotorRad+AirGapHeight+0.5*InnerToothTipHeight)*sin(ThetaSlotTip),(RotorRad+AirGapHeight+0.5*InnerToothTipHeight)*cos(ThetaSlotTip));
hi_setsegmentprop('UnSpec',MeshStatorLam,0,0,1,'<None>');    %UnSpec is a not defined boundary
  
%Set properties for the arcs corresponding to the outer parts of the air gap
hi_clearselected();
hi_selectarcsegment(0,RotorRad+AirGapHeight);
hi_selectarcsegment((RotorRad+AirGapHeight)*sin(SlotPitch/4+ThetaSlotTip/2),(RotorRad+AirGapHeight)*cos(SlotPitch/4+ThetaSlotTip/2));
hi_selectarcsegment(-(RotorRad+AirGapHeight)*sin(SlotPitch/4+ThetaSlotTip/2),(RotorRad+AirGapHeight)*cos(SlotPitch/4+ThetaSlotTip/2));
hi_setarcsegmentprop((MeshAirGap/(RotorRad+AirGapHeight))*180/pi,'UnSpec',0,1,'<None>');   %UnSpec is a not defined boundary
 
%Rotational copy of the stator
hi_clearselected();
hi_seteditmode('group');
hi_selectgroup(1);  %Select the stator
hi_copyrotate(0,0,SlotPitch*180/pi,Qs-1);

hi_zoomnatural();
Out=1;