%MaterialsInsetPMThermal.m
%%%%%%%%%%%
%Defines the laminations, shaft and slot materials (including current)

function [Out]=MaterialsInsetPMThermal(KappaAir,cthAir,KappaWedge,cthWedge, ...
               KappaShaft,cthShaft,KappaStatorLam,cthStatorLam,KappaRotorLam, ...
               cthRotorLam,KappaMagnet,cthMagnet,ShaftRad,MeshShaft,RotorRad, ...
               MeshRotor,MagnetHeight,AirGapHeight,MeshAirGap,p,Qs, ...
               InnerToothTipHeight,SlotPitch,StatorBackThickness,MeshWedge, ...
               KappaSlot,qSlot,cthSlot,MeshSlot,RotorAngle,StatorRad,MeshStatorLam, ...
               KappaEnc,cthEnc,EnclosureRad,MeshEnc)

%Define the materials%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Note that the stator slot material is added further below

%Define air as a material
hi_addmaterial('AirMat',KappaAir,KappaAir,0,cthAir); 

%Define the slot wedge material
hi_addmaterial('SlotWedgeMat',KappaWedge,KappaWedge,0,cthWedge); 

%Define the shaft material
hi_addmaterial('ShaftMat',KappaShaft,KappaShaft,0,cthShaft); 

%Define the stator and rotor lamination materials
hi_addmaterial('StatorLam',KappaStatorLam,KappaStatorLam,0,cthStatorLam); 
hi_addmaterial('RotorLam',KappaRotorLam,KappaRotorLam,0,cthRotorLam); 

%Define the permanent-magnet material'
hi_addmaterial('PermanentMagnet',KappaMagnet,KappaMagnet,0,cthMagnet); 

%Define the stator-enclosure material'
hi_addmaterial('StatorEnc',KappaEnc,KappaEnc,0,cthEnc); 

%Add the materials%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Add the shaft material
hi_clearselected();
hi_addblocklabel(0,ShaftRad/2);
hi_selectlabel(0,ShaftRad/2);
hi_setblockprop('ShaftMat',0,MeshShaft,2);

%Add the rotor lamination material
hi_clearselected();
hi_addblocklabel(0,(RotorRad+ShaftRad)/2);
hi_selectlabel(0,(RotorRad+ShaftRad)/2);
hi_setblockprop('RotorLam',0,MeshRotor,2);

%Add the air gap material
hi_clearselected();
hi_addblocklabel(0,RotorRad+MagnetHeight/2+AirGapHeight/2);
hi_selectlabel(0,RotorRad+MagnetHeight/2+AirGapHeight/2);
hi_setblockprop('AirMat',0,MeshAirGap,2);

%Add the permanent-magnet material
for n=1:p
    hi_clearselected();
    hi_addblocklabel(-(RotorRad+MagnetHeight/2)*sin((n-1)*2*pi/p),(RotorRad+MagnetHeight/2)*cos((n-1)*2*pi/p));
    hi_selectlabel(-(RotorRad+MagnetHeight/2)*sin((n-1)*2*pi/p),(RotorRad+MagnetHeight/2)*cos((n-1)*2*pi/p));
    if rem(n,2)==0
        %South poles
        hi_setblockprop('PermanentMagnet',0,MeshAirGap,2);
    else
        %North poles
        hi_setblockprop('PermanentMagnet',0,MeshAirGap,2);
    end
end

%Add the stator lamination materials
for n=1:1:Qs
    hi_clearselected();
    hi_addblocklabel((StatorRad-0.5*StatorBackThickness)*sin(-(n-1)*SlotPitch),(StatorRad-0.5*StatorBackThickness)*cos((n-1)*SlotPitch));
    hi_selectlabel((StatorRad-0.5*StatorBackThickness)*sin(-(n-1)*SlotPitch),(StatorRad-0.5*StatorBackThickness)*cos((n-1)*SlotPitch));
    hi_setblockprop('StatorLam',0,MeshStatorLam,1);
    hi_clearselected();
end

%Add the slot wedge materials
R=RotorRad+AirGapHeight+0.5*InnerToothTipHeight;
for n=1:1:Qs
    hi_clearselected();
    hi_addblocklabel(R*sin(-(n-1)*SlotPitch),R*cos((n-1)*SlotPitch));
    hi_selectlabel(R*sin(-(n-1)*SlotPitch),R*cos((n-1)*SlotPitch));
    hi_setblockprop('SlotWedgeMat',0,MeshWedge,1);
end

%Add phase A positive slot labels
hi_clearselected();
for n=1:1:Qs/(3*p)
    APos(n,:)=sprintf('A%d+',n);
end
%Add phase A negative slot labels
for n=1:1:Qs/(3*p)
    AMin(n,:)=sprintf('A%d-',n);
end
%Add phase B positive slot labels
for n=1:1:Qs/(3*p)
    BPos(n,:)=sprintf('B%d+',n);
end
%Add phase B negative slot labels
for n=1:1:Qs/(3*p)
    BMin(n,:)=sprintf('B%d-',n);
end
%Add phase B positive slot labels
for n=1:1:Qs/(3*p)
    CPos(n,:)=sprintf('C%d+',n);
end
%Add phase B negative slot labels
for n=1:1:Qs/(3*p)
    Cmin(n,:)=sprintf('C%d-',n);
end

SlotLabels=[];
for d=1:p/2
    SlotLabels=[SlotLabels; APos; Cmin; BPos; AMin; CPos; BMin];
end

%Define the stator slot materials
for n=1:length(SlotLabels(:,1))
    hi_addmaterial(SlotLabels(n,:),KappaSlot,KappaSlot,qSlot,cthSlot); 
end

%Add the stator slot material
R=RotorRad+AirGapHeight+InnerToothTipHeight+0.5*(StatorRad-StatorBackThickness-RotorRad-AirGapHeight-InnerToothTipHeight);
for n=1:1:Qs
    hi_clearselected();
    hi_addblocklabel(R*sin(-(n-1)*SlotPitch),R*cos((n-1)*SlotPitch));
    hi_selectlabel(R*sin(-(n-1)*SlotPitch),R*cos((n-1)*SlotPitch));
    if (SlotLabels(n,1)=='A' && SlotLabels(n,3)=='+')
        hi_setblockprop(SlotLabels(n,:),0,MeshSlot,1);
    end
    if (SlotLabels(n,1)=='A' && SlotLabels(n,3)=='-')
        hi_setblockprop(SlotLabels(n,:),0,MeshSlot,1);        
    end
    if (SlotLabels(n,1)=='B' && SlotLabels(n,3)=='+')
        hi_setblockprop(SlotLabels(n,:),0,MeshSlot,1);        
    end
    if (SlotLabels(n,1)=='B' && SlotLabels(n,3)=='-')
        hi_setblockprop(SlotLabels(n,:),0,MeshSlot,1);        
    end
    if (SlotLabels(n,1)=='C' && SlotLabels(n,3)=='+')
        hi_setblockprop(SlotLabels(n,:),0,MeshSlot,1);        
    end
    if (SlotLabels(n,1)=='C' && SlotLabels(n,3)=='-')
        hi_setblockprop(SlotLabels(n,:),0,MeshSlot,1);        
    end
end

%Add the stator-enclosure material
hi_clearselected();
hi_addblocklabel(0,StatorRad/2+EnclosureRad/2);
hi_selectlabel(0,StatorRad/2+EnclosureRad/2);
hi_setblockprop('StatorEnc',0,MeshEnc,1);

%Rotate the rotor to the correct rotor position
hi_clearselected();
hi_seteditmode('group');
hi_selectgroup(2);
hi_moverotate(0,0,((Qs/(3*p)-1)*pi/Qs)*180/pi+180/p+RotorAngle*180/pi);

hi_clearselected();
hi_refreshview();
hi_zoomnatural();
Out=1;