%ProblemData.m
%%%%%%%%%%%%%%
%Input data used in the FEMM simulation 

%Pole number and geometrical data of the stator%%%%%%%%%%%%%%%%%%%%%%%%%%%%
p=4;                        %Number of poles [-]
Qs=3*p*3;                   %Number of stator slots [-]
ActiveL=0.958*0.1353;       %Active machine length (stacking factor included) [m]
ShaftRad=17.5e-3;           %Shaft radius [m]
RotorRad=51.685e-3;         %Rotor radius [m]
StatorRad=80.8e-3;          %Stator outer radius [m]
AirGapHeight=0.315e-3;      %Airgap height [m]
SlotPitch=2*pi/Qs;          %Stator slot pitch [rad]
PolePitch=2*pi/p;           %Pole pitch [rad]
InnerToothTipHeight=0.8e-3; %Inner tooth tip height [m]
OuterToothTipHeight=0.8e-3; %Outer tooth tip height [m]
StatorBackThickness=19.35e-3;  %Thickness of stator back [m]
ToothWidth=4.4e-3;          %Tooth width [m]
ToothOpeningWidth=2.4e-3;   %Tooth opening width [m]
ToothHeight=14.6e-3;        %Tooth height (straight part only) [m]

%Rotor data%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Qr=26;                                      %Number of rotor slots [-]
RotorSlotPitch=2*pi/Qr;                     %Rotor slot pitch [rad]
RotorSlotDepth=3.4e-3;                      %Distance from outer rotor radius to widest part of rotor slot [m]
RotorSlotHeight=12.7e-3;                    %Distance from widest part of rotor slot to bottom of rotor slot [m]
RotorSlotOpeningWidth=1e-3;                 %Width of rotor slot opening [m]
InnerRotorSlotWidth=1.8e-3;                 %Innermost width of a rotor slot [m]
OuterRotorSlotWidth=5.42e-3;                %Outer width of a rotor slot (widest distance) [m]
RotorBarConductivity=(1/1.23)*27.0;         %Rotor bar electrical conductivity [MS/m] (Copper=58 MS/m, Aluminium=35.5 MS/m at 20 degC, 27.0 MS/m at 100 degC)
RotorBarConductivity=(1/1.23)*35.5;         %Rotor bar electrical conductivity [MS/m] (Copper=58 MS/m, Aluminium=35.5 MS/m at 20 degC, 27.0 MS/m at 100 degC)
muRotorBar=1.0;                             %Relative permeability of the rotor bar material [-]
Skew=RotorSlotPitch/SlotPitch;              %Skew of rotor expressed in number of STATOR slots [-]

%Stator winding data%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
WireConductivity=58;            %Electrical conductivity [MS/m] (Copper=58 MS/m)
Turns=155/3;                    %Number of turns in one slot [-]        
WireDiam=sqrt(3)*0.55e-3;       %Equivalent wire diameter of each turn [m]        
SlipFreq=0*5;                   %Slip frequency [Hz]
iPhase=0.5*3.6*sqrt(2);         %Peak phase current [A]

ia=iPhase;                      %a-phase phasor
ib=iPhase*(-1/2-j*sqrt(3)/2);   %b-phase phasor
ic=iPhase*(-1/2+j*sqrt(3)/2);   %c-phase phasor

%Material data%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
muWedge=1;  %Relative permeability of the (linear) stator slot wedge material [-]
muShaft=1;  %Relative permeability of the (linear) shaft material [-]

%BH-curve for the stator lamination
%BStatorLam=[0 0.5 1.0 1.5 2 2.5];
%HStatorLam=[0 120 240 360 480 600];

%%M700-50A from www.sura.se (accessed 2013-02-01)
%BStatorLam=0:0.1:1.8;
%HStatorLam=[0 67.8 88.3 99.2 108 116 124 132 142 152 164 180 206 254 363 690 1760 4230 8130];

%M600-50A from www.sura.se (accessed 2013-03-04)
BStatorLam=0:0.1:1.8;
HStatorLam=[0 65.6 83.8 94.1 103 110 118 127 136 147 159 177 205 255 370 718 1840 4370 8330];
 
% %Compensate for sinusoidal excitation only
% %M600-50A from www.sura.se (accessed 2013-03-04)
% BStatorLam=-1.8:0.1:1.8;
% HStatorLam=[0 65.6 83.8 94.1 103 110 118 127 136 147 159 177 205 255 370 718 1840 4370 8330];
% HStatorLam=[-HStatorLam(end:-1:2) HStatorLam(1:end)];
% dtheta=0.001;
% theta=0:dtheta:2*pi-dtheta;
% for i=1:length(HStatorLam)
%     Hsin=HStatorLam(i).*sin(theta);
%     Bsin=interp1(HStatorLam,BStatorLam,Hsin);
%     BSIN=fft(Bsin);
%     BStatorLamComp(i)=2*abs(BSIN(2))/length(BSIN);
%     if HStatorLam(i)<0
%         BStatorLamComp(i)=-BStatorLamComp(i);
%     end
% end
% index=find(HStatorLam==0); 
% BStatorLam=BStatorLamComp(index:end); %BH-data for the first quadrant (B>=0, H>=0) required as input to FEMM
% HStatorLam=HStatorLam(index:end);

%BH-curve for the rotor lamination 
BRotorLam=BStatorLam;
HRotorLam=HStatorLam;

%Mesh density variables%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
MeshStatorLam=0.1*(StatorRad-RotorRad-AirGapHeight); %Max length of mesh elements [m]
MeshSlot=MeshStatorLam; %Max length of mesh elements [m]
MeshAirGap=0.3*AirGapHeight; %Max length of mesh elements [m]
MeshWedge=MeshStatorLam; %Max length of mesh elements [m]
MeshRotor=MeshStatorLam; %Max length of mesh elements [m]
MeshShaft=MeshStatorLam; %Max length of mesh elements [m]
NoOfArcSegments=3; %Number of segments in one arc [-]