%RotorDataInsetPM.m
%%%%%%%%%%%%%%
%Input data for the rotor (inset mounted magnets) used in the FEMM simulation 

function [ShaftRad,RotorRad,MagnetHeight,MagnetArcAngle,MagnetLeakageFluxBarrierAngle, ...
          muShaft,muMagnet,HcMag,MagnetConductivity,BRotorLam,HRotorLam, ...
          AirGapHeight,KappaShaft,cthShaft,KappaRotorLam,cthRotorLam, ...
          KappaMagnet,cthMagnet]=RotorDataInsetPM(BStatorLam,HStatorLam,StatorRad,StatorBackThickness, ...
          ToothHeight,InnerToothTipHeight,p)

%Rotor geomatrical data%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ShaftRad=17.5e-3;                           %Shaft radius [m]
RotorRad=40e-3;                             %Outer radius of rotor lamination [m]
MagnetHeight=4.85e-3;                       %Height of rotor magnets [m]
MagnetArcAngle=120*(2*pi/(180*p));          %Magnet arcangle [rad] 
MagnetLeakageFluxBarrierAngle=2*pi/180;     %Magnet leakage-flux barrier angle [rad]

%Material and thermal data%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
muShaft=1;                      %Relative permeability of the (linear) shaft material [-]
muMagnet=1.05;                  %Relative permeability of the (linear) permanent magnet [s]
HcMag=8.336687495289757e+05;    %Permanent-magnet coercitivity [A/m]     
MagnetConductivity=10000;       %Magnet electrical conductivity [MS/m] (not used in dc-problems)

%BH-curve for the rotor lamination (same as stator)
BRotorLam=BStatorLam;
HRotorLam=HStatorLam;

%Thermal properties of the rotor shaft
KappaShaft=54;                      %Thermal conductivity of the rotor shaft [W/(m*K)]
rhoShaft=7650;                      %Density of the rotor shaft [kg/m^3]
cthShaft=(425/rhoShaft)*10^(-6);    %Specific heat capacity of the shaft [MJ/(m^3*K)]

%Thermal properties of the rotor lamination
KappaRotorLam=28;                          %Thermal conductivity of the rotor larmination [W/(m*K)]
rhoRotorLam=7650;                          %Density of the rotor lamination [kg/m^3]
cthRotorLam=(486/rhoRotorLam)*10^(-6);     %Specific heat capacity of the rotor lamination [MJ/(m^3*K)]

%Thermal properties of the permanent magnets
KappaMagnet=8;                          %Thermal conductivity of the permanent magnets [W/(m*K)]
rhoMagnet=7600;                         %Density of the permanent magnets [kg/m^3]
cthMagnet=(450/rhoMagnet)*10^(-6);      %Specific heat capacity of the permanent magnets [MJ/(m^3*K)]

%Compute the resulting air-gap height (distance between inner stator radius and outer radius of the rotor lamination)
AirGapHeight=StatorRad-StatorBackThickness-ToothHeight-InnerToothTipHeight-RotorRad;
