close all; clear all; clc;

global HandleToFEMM;

WorkDir=cd;

j=sqrt(-1); %Define the imaginary unit

addpath('C:\TPFAPPS\femm42\mfiles'); %Path to FEMM commands called from Matlab
FEMMOutputDir='C:\EJ2210\Computer assignment\';  %Folder where FEMM output is stored
MagFileName='PMMagnetic';   %Name of FEMM data (.fem file) corresponding to magnetic simulation
ThermFileName='PMThermal';   %Name of FEMM data (.fem file) corresponding to the thermal simulation

matlabpool(2)
parfor SimNo=1:2

%closefemm;
%for SimNo=1:2
    
    mu0=4*pi*10^(-7);               %Define mu0
    
    if SimNo==1 %Run the magnetic simulation
        
                openfemm;
        
                %Read stator data (and set the rotor angle)
                [p,Qs,ActiveL,StatorRad,InnerToothTipHeight,OuterToothTipHeight, ...
                    StatorBackThickness,ToothWidth,ToothOpeningWidth,ToothHeight, ...
                    id,iq,Turns,WireDiam,RotorAngle,WireConductivity, ...
                    muWedge,muLamination,BStatorLam,HStatorLam, ...
                    SlotPitch,PolePitch,ia,ib,ic,TAmbient,hCyl, ...
                    KappaAir,cthAir,KappaWedge,cthWedge, ...
                    KappaStatorLam,cthStatorLam,KappaSlot, ...
                    cthSlot,qSlot,EnclosureRad,KappaEnc,cthEnc,muEnc]=StatorData();
        
                %Read rotor data
                [ShaftRad,RotorRad,MagnetHeight,MagnetArcAngle,MagnetLeakageFluxBarrierAngle, ...
                    muShaft,muMagnet,HcMag,MagnetConductivity,BRotorLam,HRotorLam, ...
                    AirGapHeight,KappaShaft,cthShaft,KappaRotorLam,cthRotorLam, ...
                    KappaMagnet,cthMagnet]=RotorDataInsetPM(BStatorLam,HStatorLam,StatorRad,StatorBackThickness, ...
                    ToothHeight,InnerToothTipHeight,p);
        
                %Read mesh data
                [MeshStatorLam,MeshSlot,MeshAirGap,MeshWedge,...
                    MeshRotor,MeshShaft,MeshEnc,NoOfArcSegments]=MeshDataMagn(StatorRad,RotorRad,AirGapHeight);
        
                %Create a new magnetic problem
                newdocument(0);
                mi_probdef(0,'meters','planar',1e-8,ActiveL,30);
        
                %Draw the stator geometry in the FEMM window
                [Out]=GeometryStatorMagn(ia,ib,ic,StatorRad,SlotPitch,RotorRad, ...
                    AirGapHeight,ToothOpeningWidth,InnerToothTipHeight, ...
                    OuterToothTipHeight,NoOfArcSegments,ToothWidth, ...
                    ToothHeight,MeshStatorLam,StatorBackThickness, ...
                    MeshAirGap,Qs,EnclosureRad);
        
                %Draw the rotor geometry in the FEMM window
                [Out]=GeometryRotorInsetPMMagn(ShaftRad,PolePitch,NoOfArcSegments, ...
                    RotorRad,MagnetHeight,MagnetArcAngle,MagnetLeakageFluxBarrierAngle, ...
                    MeshShaft,MeshRotor,MeshAirGap,p);
        
                %Define the materials and label the different motor parts
                [Out]=MaterialsInsetPMMagn(muWedge,muShaft,BStatorLam,HStatorLam, ...
                    BRotorLam,HRotorLam,muMagnet,HcMag,MagnetConductivity,...
                    ActiveL,ShaftRad,MeshShaft,RotorRad,MeshRotor,MagnetHeight, ...
                    AirGapHeight,MeshAirGap,StatorRad,StatorBackThickness, ...
                    SlotPitch,MeshStatorLam,InnerToothTipHeight,Qs,MeshWedge, ...
                    p,Turns,RotorAngle,MeshSlot,muEnc,EnclosureRad,MeshEnc);
        
                cd(FEMMOutputDir)
                %Delete old problem (if existing)
                delete(strcat(MagFileName,'.fem'));  %Problem formulation data stored in .fem-file
                delete(strcat(MagFileName,'.ans'));  %Post-processor data stored in .ans-file
        
                %Save the problem
                mi_saveas(strcat(FEMMOutputDir,MagFileName,'.fem'));
        
                %Create the mesh
                mi_createmesh();
        
                %Solve the problem
                mi_analyze()
        
                %Load and display the solution
                mi_loadsolution();
        
                cd(WorkDir);
        
    else %Run the thermal simulation
        openfemm;
        
        %Read stator data (and set the rotor angle)
        [p,Qs,ActiveL,StatorRad,InnerToothTipHeight,OuterToothTipHeight, ...
            StatorBackThickness,ToothWidth,ToothOpeningWidth,ToothHeight, ...
            id,iq,Turns,WireDiam,RotorAngle,WireConductivity, ...
            muWedge,muLamination,BStatorLam,HStatorLam, ...
            SlotPitch,PolePitch,ia,ib,ic,TAmbient,hCyl, ...
            KappaAir,cthAir,KappaWedge,cthWedge, ...
            KappaStatorLam,cthStatorLam,KappaSlot, ...
            cthSlot,qSlot,EnclosureRad,KappaEnc,cthEnc,muEnc]=StatorData();
        
        %Read rotor data
        [ShaftRad,RotorRad,MagnetHeight,MagnetArcAngle,MagnetLeakageFluxBarrierAngle, ...
            muShaft,muMagnet,HcMag,MagnetConductivity,BRotorLam,HRotorLam, ...
            AirGapHeight,KappaShaft,cthShaft,KappaRotorLam,cthRotorLam, ...
            KappaMagnet,cthMagnet]=RotorDataInsetPM(BStatorLam,HStatorLam,StatorRad,StatorBackThickness, ...
            ToothHeight,InnerToothTipHeight,p);
        
        %Read mesh data
        [MeshStatorLam,MeshSlot,MeshAirGap,MeshWedge,...
            MeshRotor,MeshShaft,MeshEnc,NoOfArcSegments]=MeshDataThermal(StatorRad,RotorRad,AirGapHeight);
        
        %Create a new thermal problem
        newdocument(2);
        hi_probdef('meters','planar',1e-8,ActiveL,30);
        
        %Draw the stator geometry in the FEMM window
        [Out]=GeometryStatorThermal(ia,ib,ic,StatorRad,SlotPitch,RotorRad, ...
            AirGapHeight,ToothOpeningWidth,InnerToothTipHeight, ...
            OuterToothTipHeight,NoOfArcSegments,ToothWidth, ...
            ToothHeight,MeshStatorLam,StatorBackThickness, ...
            MeshAirGap,Qs,TAmbient,hCyl,EnclosureRad);
        
        %Draw the rotor geometry in the FEMM window
        [Out]=GeometryRotorInsetPMThermal(ShaftRad,PolePitch,NoOfArcSegments, ...
            RotorRad,MagnetHeight,MagnetArcAngle,MagnetLeakageFluxBarrierAngle, ...
            MeshShaft,MeshRotor,MeshAirGap,p);
        
        %Define the materials and label the different motor parts
        [Out]=MaterialsInsetPMThermal(KappaAir,cthAir,KappaWedge,cthWedge, ...
            KappaShaft,cthShaft,KappaStatorLam,cthStatorLam,KappaRotorLam, ...
            cthRotorLam,KappaMagnet,cthMagnet,ShaftRad,MeshShaft,RotorRad, ...
            MeshRotor,MagnetHeight,AirGapHeight,MeshAirGap,p,Qs, ...
            InnerToothTipHeight,SlotPitch,StatorBackThickness,MeshWedge, ...
            KappaSlot,qSlot,cthSlot,MeshSlot,RotorAngle,StatorRad,MeshStatorLam, ...
            KappaEnc,cthEnc,EnclosureRad,MeshEnc);
        
        cd(FEMMOutputDir)
        %Delete old problem (if existing)
        delete(strcat(ThermFileName,'.feh'));  %Problem formulation data stored in .fem-file
        delete(strcat(ThermFileName,'.anh'));  %Post-processor data stored in .ans-file
        
        %Save the problem
        hi_saveas(strcat(FEMMOutputDir,ThermFileName,'.feh'));
        
        %Create the mesh
        hi_createmesh();
        
        %Solve the problem
        hi_analyze()
        
        %Load and display the solution
        hi_loadsolution();
        
        cd(WorkDir);
    end
end
matlabpool close;

%Close the FEMM window (if opened)
% closefemm;
%
% %Open the FEMM window (in which the FEM computations are executed)
% openfemm;
%

%Clear all selected contours (if any)
% mo_clearcontour;
%
% CircPropA=mo_getcircuitproperties('A');
% CircPropB=mo_getcircuitproperties('B');
% CircPropC=mo_getcircuitproperties('C');
% CurrPhaseA=CircPropA(1); VoltPhaseA=CircPropA(2); PsiA=-CircPropA(3);
% CurrPhaseB=CircPropB(1); VoltPhaseB=CircPropB(2); PsiB=-CircPropB(3);
% CurrPhaseC=CircPropC(1); VoltPhaseC=CircPropC(2); PsiC=-CircPropC(3);
%
% Psid=(2/3)*(cos(RotorAngle*p/2)*PsiA+cos(RotorAngle*p/2-2*pi/3)*PsiB+cos(RotorAngle*p/2+2*pi/3)*PsiC);
% Psiq=(2/3)*(-sin(RotorAngle*p/2)*PsiA-sin(RotorAngle*p/2-2*pi/3)*PsiB-sin(RotorAngle*p/2+2*pi/3)*PsiC);
% iaVect=CurrPhaseA;
% ibVect=CurrPhaseB;
% icVect=CurrPhaseC;

% pause;
% %Close down both FEMM instances
% HandleToFEMM=MagSimHandle;
% closefemm;
% HandleToFEMM=ThermSimHandle;
% closefemm;
